package com.abi.qms.platform.controller.console;

import com.abi.qms.platform.dto.req.ActiveBoxCodeReq;
import com.abi.qms.platform.dto.req.GenerateBarCodeReq;
import com.abi.qms.platform.dto.req.ListQrBoxCodeMappingReq;
import com.abi.qms.platform.dto.res.ListQrBoxCodeMappingRes;
import com.abi.qms.platform.dto.res.QrBoxCodeUploadRes;
import com.abi.qms.platform.service.QrBoxMappingService;
import com.abi.task.common.api.base.BaseResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/**
 * @author: fangxinjian
 * @date: 2021/05/27 11:15
 * @description: 箱码合一
 */
@RestController
@Api(tags = "箱码合一")
@RequestMapping("/boxCodeUnity")
public class QrBoxCodeUnityController {

    @Autowired
    private QrBoxMappingService qrBoxMappingService;

    @ApiOperation("生成条形码")
    @PostMapping("/generateBarCode")
    public BaseResponse generateBarCode(@RequestBody GenerateBarCodeReq generateBarCodeReq) {

        qrBoxMappingService.generateBarCode(generateBarCodeReq);
        return BaseResponse.create();
    }

    @ApiOperation("箱码合一文件上传")
    @PostMapping("/uploads")
    public BaseResponse<QrBoxCodeUploadRes> uploadCodeFiles(HttpServletRequest request) {

        //拿到文件
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> map = multipartRequest.getFileMap();

        QrBoxCodeUploadRes res = qrBoxMappingService.uploadCodeFiles(map);

        return BaseResponse.create(res);

    }

    @ApiOperation("分页查询箱码合一列表")
    @GetMapping("/listQrBoxCodeMapping")
    public BaseResponse<ListQrBoxCodeMappingRes> listQrBoxCodeMapping(ListQrBoxCodeMappingReq listQrBoxCodeMappingReq) {

        ListQrBoxCodeMappingRes res = qrBoxMappingService.listQrBoxCodeMapping(listQrBoxCodeMappingReq);
        return BaseResponse.create(res);
    }

    @ApiOperation("激活/作废码包")
    @PostMapping("/active")
    public BaseResponse activeBoxCode(@RequestBody ActiveBoxCodeReq activeBoxCodeReq) {

        qrBoxMappingService.activeBoxCode(activeBoxCodeReq);
        return BaseResponse.create();
    }


}
